import java.awt.image.BufferedImage;

public class PixelBufferFilter2AsBufferedImageFilter implements BufferedImageFilter {
	private PixelBufferFilter2 pixelBufferFilter;
	private int[] inPixelBuffer;
	private int[] outPixelBuffer;
	
	public PixelBufferFilter2AsBufferedImageFilter(PixelBufferFilter2 pixelBufferFilter) {
		this.pixelBufferFilter = pixelBufferFilter;
		this.inPixelBuffer = null;
		this.outPixelBuffer = null;
	}
	
	public void filter(BufferedImage img) {
		int width = img.getWidth();
		int height = img.getHeight();
		int numPixels = width*height;
		
		// Ensure the size of the pixel buffer matches the number of pixels in the image
		if ((inPixelBuffer == null) || (inPixelBuffer.length != numPixels)) {
			inPixelBuffer = new int[numPixels];
			outPixelBuffer = new int[numPixels];
		}
		
		// Read the image's pixels into the pixel buffer
		BufferedImages.getAllRGB(img, inPixelBuffer);
		
		// Filter the contents of the pixel buffer
		pixelBufferFilter.filter(width, height, inPixelBuffer, outPixelBuffer);
		
		// Store the pixel buffer back into the original image
		BufferedImages.setAllRGB(img, outPixelBuffer);
	}
	
	public String toString() {
		return pixelBufferFilter.toString();
	}
}