import java.awt.image.BufferedImage;

/**
 * Represents a filter that can be applied to a BufferedImage,
 * along with its rectangular array of pixels.
 */
public interface PixelBufferToBufferedImageFilter {
	/**
	 * Transforms the pixels in the specified BufferedImage.
	 * 
	 * @param width		width of the pixel buffer
	 * @param height	height of the pixel buffer
	 * @param inPixels	the input pixel buffer;
	 * 					each element of the array corresponds to one pixel (usually in ARGB format);
	 * 					pixels are arranged in left-to-right, top-to-bottom fashion
	 * @param inImg		the input image
	 * @param outImg	the output image
	 * 
	 */
	public void filter(int width, int height, int[] inPixels,
	                   BufferedImage inImg, BufferedImage outImg);
	
	/**
	 * @return			the name of this filter
	 */
	public String toString();
}